@@ -1,7 +1,7 @@
 
 package PRANG::Marshaller;
 BEGIN {
-  $PRANG::Marshaller::VERSION = '0.13';
+  $PRANG::Marshaller::VERSION = '0.14';
 }
 
 use Moose;
@@ -27,8 +27,10 @@ has 'class' =>
 	handles => [qw(marshall_in_element to_libxml)],
 	trigger => sub {
 	my $self = shift;
-	my $class = $self->class;
-	if ( !$class->can("marshall_in_element") ) {
+	my $class = shift;
+
+	if ( !$class->can("marshall_in_element") && ! $class->does_role('PRANG::Graph') ) {
+
 		$class = $class->name if ref $class;
 		die "Can't marshall $class; didn't 'use PRANG::Graph' ?";
 	}
@@ -150,7 +152,7 @@ sub parse {
 		xsi => $xsi,
 		prefix => "",
 	);
-
+	
 	my $rv = $self->class->marshall_in_element(
 		$rootNode,
 		$context,
